.. _credits:

*******
Credits
*******


Matplotlib was written by John D. Hunter, with contributions from
an ever-increasing number of users and developers.
The current co-lead developers are Michael Droettboom
and Thomas A. Caswell; they are assisted by many
`active
<https://www.openhub.net/p/matplotlib/contributors>`_ developers.

The following is a list of contributors extracted from the
git revision control history of the project:

4over7,
Aaron Boushley,
Acanthostega,
Adam Ginsburg,
Adam Heck,
Adam Ortiz,
Adrian Price-Whelan,
Adrien F. Vincent,
Ahmet Bakan,
Alan Du,
Alejandro Dubrovsky,
Alex C. Szatmary,
Alex Loew,
Alexander Taylor,
Alexei Colin,
Ali Mehdi,
Alistair Muldal,
Allan Haldane,
Amit Aronovitch,
Amy,
AmyTeegarden,
Andrea Bedini,
Andreas Hilboll,
Andreas Wallner,
Andrew Dawson,
Andrew Merrill,
Andrew Straw,
Andy Zhu,
Anton Akhmerov,
Antony Lee,
Arie,
Ariel Hernán Curiale,
Arnaud Gardelein,
Arpad Horvath,
Aseem Bansal,
Behram Mistree,
Ben Cohen,
Ben Gamari,
Ben Keller,
Ben Root,
Benjamin Reedlunn,
Binglin Chang,
Bradley M. Froehle,
Brandon Liu,
Brett Cannon,
Brett Graham,
Brian Mattern,
Brian McLaughlin,
Bruno Beltran,
CJ Carey,
Cameron Bates,
Cameron Davidson-Pilon,
Carissa Brittain,
Carl Michal,
Carwyn Pelley,
Casey Webster,
Casper van der Wel,
Charles Moad,
Chris Beaumont,
Chris G,
Christian Brueffer,
Christian Stade-Schuldt,
Christoph Dann,
Christoph Gohlke,
Christoph Hoffmann,
Cimarron Mittelsteadt,
Corey Farwell,
Craig M,
Craig Tenney,
Damon McDougall,
Dan Hickstein,
Daniel Hyams,
Daniel O'Connor,
Dara Adib,
Darren Dale,
David Anderson,
David Haberthür,
David Huard,
David Kaplan,
David Kua,
David Trémouilles,
Dean Malmgren,
Dmitry Lupyan,
DonaldSeo,
Dora Fraeman,
Duncan Macleod,
Edin Salkovic,
Elena Glassman,
Elias Pipping,
Elliott Sales de Andrade,
Emil Mikulic,
Eric Dill,
Eric Firing,
Eric Ma,
Eric O. LEBIGOT (EOL),
Erik Bray,
Eugen Beck,
Eugene Yurtsev,
Evan Davey,
Ezra Peisach,
Fabien Maussion,
Fabio Zanini,
Federico Ariza,
Felipe,
Fernando Perez,
Filipe Fernandes,
Florian Rhiem,
Francesco Montesano,
Francis Colas,
François Magimel,
Gaute Hope,
Gellule Xg,
Geoffroy Billotey,
Gerald Storer,
Giovanni,
Graham Poulter,
Gregory Ashton,
Gregory R. Lee,
Grégory Lielens,
Guillaume Gay,
Gustavo Braganca,
Hans Dembinski,
Hans Meine,
Hans Moritz Günther,
Hassan Kibirige,
Holger Peters,
Hubert Holin,
Ian Thomas,
Ignas Anikevicius (gns_ank),
Ilia Kurenkov,
Ioannis Filippidis,
Ismo Toijala,
J. Goutin,
Jack Kelly,
Jae-Joon Lee,
Jaime Fernandez,
Jake Vanderplas,
James A. Bednar,
James Pallister,
James R. Evans,
JamesMakela,
Jan Schulz,
Jan-Philip Gehrcke,
Jan-willem De Bleser,
Jarrod Millman,
Jascha Ulrich,
Jason Grout,
Jason Liw Yan Chong,
Jason Miller,
JayP16,
Jeff Lutgen,
Jeff Whitaker,
Jeffrey Bingham,
Jens Hedegaard Nielsen,
Jeremy Fix,
Jeremy O'Donoghue,
Jeremy Thurgood,
Jessica B. Hamrick,
Jim Radford,
Jochen Voss,
Jody Klymak,
Joe Kington,
Joel B. Mohler,
John Hunter,
Jonathan Waltman,
Jorrit Wronski,
Josef Heinen,
Joseph Jon Booker,
José Ricardo,
Jouni K. Seppänen,
Julian Mehne,
Julian Taylor,
JulianCienfuegos,
Julien Lhermitte,
Julien Schueller,
Julien Woillez,
Julien-Charles Lévesque,
Kanwar245,
Katy Huff,
Ken McIvor,
Kevin Chan,
Kevin Davies,
Kevin Keating,
Kimmo Palin,
Konrad Förstner,
Konstantin Tretyakov,
Kristen M. Thyng,
Lance Hepler,
Larry Bradley,
Leeonadoh,
Lennart Fricke,
Leo Singer,
Levi Kilcher,
Lion Krischer,
Lodato Luciano,
Lori J,
Loïc Estève,
Loïc Séguin-C,
Magnus Nord,
Majid alDosari,
Maksym P,
Manuel GOACOLOU,
Manuel Metz,
Marc Abramowitz,
Marcos Duarte,
Marek Rudnicki,
Marianne Corvellec,
Marin Gilles,
Markus Roth,
Markus Rothe,
Martin Dengler,
Martin Fitzpatrick,
Martin Spacek,
Martin Teichmann,
Martin Thoma,
Martin Ueding,
Masud Rahman,
Mathieu Duponchelle,
Matt Giuca,
Matt Klein,
Matt Li,
Matt Newville,
Matt Shen,
Matt Terry,
Matthew Brett,
Matthew Emmett,
Matthias Bussonnier,
Matthieu Caneill,
Matěj Týč,
Maximilian Albert,
Maximilian Trescher,
Mellissa Cross,
Michael,
Michael Droettboom,
Michael Sarahan,
Michael Welter,
Michiel de Hoon,
Michka Popoff,
Mike Kaufman,
Mikhail Korobov,
MinRK,
Minty Zhang,
MirandaXM,
Miriam Sierig,
Muhammad Mehdi,
Neil,
Neil Crighton,
Nelle Varoquaux,
Niall Robinson,
Nic Eggert,
Nicholas Devenish,
Nick Semenkovich,
Nicolas P. Rougier,
Nicolas Pinto,
Nikita Kniazev,
Niklas Koep,
Nikolay Vyahhi,
Norbert Nemec,
OceanWolf,
Oleg Selivanov,
Olga Botvinnik,
Oliver Willekens,
Parfenov Sergey,
Pascal Bugnion,
Patrick Chen,
Patrick Marsh,
Paul,
Paul Barret,
Paul G,
Paul Hobson,
Paul Ivanov,
Pauli Virtanen,
Per Parker,
Perry Greenfield,
Pete Bachant,
Peter Iannucci,
Peter St. John,
Peter Würtz,
Phil Elson,
Pierre Haessig,
Pim Schellart,
Piti Ongmongkolkul,
Puneeth Chaganti,
Ramiro Gómez,
Randy Olson,
Reinier Heeres,
Remi Rampin,
Richard Hattersley,
Richard Trieu,
Ricky,
Robert Johansson,
Robin Dunn,
Rohan Walker,
Roland Wirth,
Russell Owen,
RutgerK,
Ryan Blomberg,
Ryan D'Souza,
Ryan Dale,
Ryan May,
Ryan Nelson,
RyanPan,
Salil Vanvari,
Sameer D'Costa,
Sandro Tosi,
Scott Lasley,
Scott Lawrence,
Scott Stevenson,
Sebastian Pinnau,
Sebastian Raschka,
Sergey Kholodilov,
Sergey Koposov,
Silviu Tantos,
Simon Cross,
Simon Gibbons,
Skelpdar,
Skipper Seabold,
Slav Basharov,
Spencer McIntyre,
Stanley, Simon,
Stefan Lehmann,
Stefan van der Walt,
Stefano Rivera,
Stephen Horst,
Sterling Smith,
Steve Chaplin,
Steven Silvester,
Stuart Mumford,
Takafumi Arakaki,
Takeshi Kanmae,
Tamas Gal,
Thomas A Caswell,
Thomas Hisch,
Thomas Kluyver,
Thomas Lake,
Thomas Robitaille,
Thomas Spura,
Till Stensitzki,
Timo Vanwynsberghe,
Tobias Hoppe,
Tobias Megies,
Todd Jennings,
Todd Miller,
Tomas Kazmar,
Tony S Yu,
Tor Colvin,
Travis Oliphant,
Trevor Bekolay,
Ulrich Dobramysl,
Umair Idris,
Vadim Markovtsev,
Valentin Haenel,
Victor Zabalza,
Viktor Kerkez,
Vlad Seghete,
Víctor Terrón,
Víctor Zabalza,
Wen Li,
Wendell Smith,
Werner F Bruhin,
Wes Campaigne,
Wieland Hoffmann,
William Manley,
Wouter Overmeire,
Xiaowen Tang,
Yann Tambouret,
Yaron de Leeuw,
Yu Feng,
Yunfei Yang,
Yuri D'Elia,
Yuval Langer,
Zach Pincus,
Zair Mubashar,
alex,
anykraus,
arokem,
aseagram,
aszilagyi,
bblay,
bev-a-tron,
blackw1ng,
blah blah,
burrbull,
butterw,
cammil,
captainwhippet,
chadawagner,
chebee7i,
danielballan,
davidovitch,
daydreamt,
domspad,
donald,
drevicko,
e-q,
elpres,
endolith,
fardal,
ffteja,
fgb,
fibersnet,
frenchwr,
fvgoto,
gitj,
gluap,
goir,
hugadams,
insertroar,
itziakos,
jbbrokaw,
juan.gonzalez,
kcrisman,
kelsiegr,
khyox,
kikocorreoso,
kramer65,
kshramt,
lichri12,
limtaesu,
marky,
masamson,
mbyt,
mcelrath,
mdipierro,
mrkrd,
nickystringer,
nwin,
pkienzle,
profholzer,
pupssman,
rahiel,
rhoef,
rsnape,
s9w,
sdementen,
sfroid,
sohero,
spiessbuerger,
stahlous,
switham,
syngron,
torfbolt,
u55,
ugurthemaster,
vbr,
xbtsw,
and xuanyuansen.

Some earlier contributors not included above are (with apologies
to any we have missed):

Charles Twardy,
Gary Ruben,
John Gill,
David Moore,
Paul Barrett,
Jared Wahlstrand,
Jim Benson,
Paul Mcguire,
Andrew Dalke,
Nadia Dencheva,
Baptiste Carvello,
Sigve Tjoraand,
Ted Drain,
James Amundson,
Daishi Harada,
Nicolas Young,
Paul Kienzle,
John Porter,
and Jonathon Taylor.

We also thank all who have reported bugs, commented on
proposed changes, or otherwise contributed to Matplotlib's
development and usefulness.
